@@ -56,6 +56,7 @@ from google.cloud.bigquery.job import CopyJob
 from google.cloud.bigquery.job import CopyJobConfig
 from google.cloud.bigquery.job import CreateDisposition
 from google.cloud.bigquery.job import DestinationFormat
+from google.cloud.bigquery.job import DmlStats
 from google.cloud.bigquery.job import Encoding
 from google.cloud.bigquery.job import ExtractJob
 from google.cloud.bigquery.job import ExtractJobConfig
@@ -84,6 +85,7 @@ from google.cloud.bigquery.routine import DeterminismLevel
 from google.cloud.bigquery.routine import Routine
 from google.cloud.bigquery.routine import RoutineArgument
 from google.cloud.bigquery.routine import RoutineReference
+from google.cloud.bigquery.routine import RoutineType
 from google.cloud.bigquery.schema import SchemaField
 from google.cloud.bigquery.table import PartitionRange
 from google.cloud.bigquery.table import RangePartitioning
@@ -142,6 +144,7 @@ __all__ = [
     "BigtableOptions",
     "BigtableColumnFamily",
     "BigtableColumn",
+    "DmlStats",
     "CSVOptions",
     "GoogleSheetsOptions",
     "ParquetOptions",
@@ -160,6 +163,7 @@ __all__ = [
     "KeyResultStatementKind",
     "OperationType",
     "QueryPriority",
+    "RoutineType",
     "SchemaUpdateOption",
     "SourceFormat",
     "SqlTypeNames",
