@@ -191,9 +191,11 @@ _SQL_SCALAR_TYPES = frozenset(
         "DATE",
         "TIME",
         "DATETIME",
+        "INTERVAL",
         "GEOGRAPHY",
         "NUMERIC",
         "BIGNUMERIC",
+        "JSON",
     )
 )
 
