@@ -31,6 +31,7 @@ from google.cloud.bigquery.job.extract import ExtractJobConfig
 from google.cloud.bigquery.job.load import LoadJob
 from google.cloud.bigquery.job.load import LoadJobConfig
 from google.cloud.bigquery.job.query import _contains_order_by
+from google.cloud.bigquery.job.query import DmlStats
 from google.cloud.bigquery.job.query import QueryJob
 from google.cloud.bigquery.job.query import QueryJobConfig
 from google.cloud.bigquery.job.query import QueryPlanEntry
@@ -66,6 +67,7 @@ __all__ = [
     "LoadJob",
     "LoadJobConfig",
     "_contains_order_by",
+    "DmlStats",
     "QueryJob",
     "QueryJobConfig",
     "QueryPlanEntry",
